%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% gmcen is "article" style class modified                           %
% according to the guidelines of LSC final thesis.                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Author: Vytautas Petrauskas                                                 %
% vytautas.petrauskas at bti.vu.lt                                            %
% "article" style class modified according to the LSC thesis guidelines.      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ProvidesClass{gmcen}[VU LSC thesis template]
\LoadClassWithOptions{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Versija                                                                     %
\newcommand{\versija}{1.0}                                                    %
% Šablono išleidimo                                                           %
\newcommand{\sablonodata}{\today}                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% Lietuvių kalbos tvarkymo paketai %%%%%%%%%%%%%%%%%%%%%%%$$$$%%%%%%%%%%%%%%
\RequirePackage[L7x]{fontenc}                                                 %
\RequirePackage[utf8]{inputenc}                                               %
\RequirePackage{lmodern}                                                      %
\RequirePackage[english,lithuanian]{babel}                                    %
\RequirePackage[autostyle]{csquotes}                                          %
\DeclareQuoteAlias{english}{american}                                         %
\MakeOuterQuote{"}                                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% Additional packages %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Margin control:                                                             %
\RequirePackage[top=2cm,bottom=2cm,left=2.5cm,right=1.5cm]{geometry}          %
% Line spacing:                                                               %
\RequirePackage{setspace}                                                     %
% Hyperlink package:                                                          %
\RequirePackage{hyperref}                                                     % 
% Graphics package:                                                           %
\RequirePackage{graphicx}                                                     %
% Mathematics package:                                                        %
\RequirePackage{amsmath, amsfonts, amssymb}                                   %
% Mathematical symbols in bold fonts:                                         %
\usepackage{bm}                                                               %
% Optimize spacing between letters:                                           %
\RequirePackage{microtype}                                                    %    
% Indents first row in the paragraph:                                         %          
\RequirePackage{indentfirst}                                                  %
% Addition of section numbers to figures and tables:                          %          
\RequirePackage{chngcntr}                                                     %
% Formating captions of figures and tables:                                   %
\RequirePackage{caption}                                                      %
% Additional options for TOC:                                                 % 
\RequirePackage[titles]{tocloft}                                              %
% Header and footer control:                                                  %
\RequirePackage{fancyhdr}                                                     %
% Color package:                                                              %
\RequirePackage{xcolor}                                                       %
% Section style package:                                                      %
\RequirePackage{titlesec}                                                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% Naujos vartotojo komandos %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\thesisauthor}[2][]{\def\@studentas{#1}
														\def\@thesisauthor{#2}
													 }
\newcommand{\titleLT}[1]{\def\@titleLT{#1}}
\newcommand{\titleEN}[1]{\def\@titleEN{#1}}
\newcommand{\supervisor}[3][]{\def\@supervisor{#1}
							   					 \def\@supervisorpirmas{#2}
							             \def\@supervisorantras{#3}
						              }
\newcommand{\consultant}[2][]{\def\@consultantVM{#1}
														    \def\@consultant{#2}
													     }
\newcommand{\studyprogram}[1]{\def\@studyprogram{#1}}
\newcommand{\thesistype}[1]{\def\@thesistype{#1}}
\newcommand{\department}[2][]{\def\@departmentPR{#1}
													 \def\@department{#2}
													}
\newcommand{\vietametai}[2]{\def\@vieta{#1}
                            \def\@metai{#2}}

\newcommand{\VUGMC}{Vilniaus universitetas\\Gyvybės mokslų centras}
\newcommand{\VUGMCen}{Vilnius University\\Life Sciences Center}

\newcommand{\santraukosPavLT}{Santrauka}
\newcommand{\santraukosPavEN}{Abstract}

\newcommand{\patikrintiArIvestasKintamasis}[2]
{
	\@ifundefined{#1}{\PackageError{gmclt}{#2}{Command is missing}}
}

% VU collor
\definecolor{VU}{RGB}{123, 0, 63}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Title page:
\renewcommand\maketitle{
\begin{titlepage}
{\sffamily		
	\begin{center}
		% VU logo	
		\includegraphics[height=2.2cm]{cls/VU_logo}\\
		\vspace{0.5\baselineskip}
		
		\MakeUppercase{\large \VUGMCen}
		\vspace{3\baselineskip}
		
		\patikrintiArIvestasKintamasis{@thesisauthor}
		{Specify the thesis author ( command \protect\thesisauthor[Student]{Name Surname} )}
		{\large \textbf{\@thesisauthor}} \\
		\vspace{2\baselineskip}
		
		\patikrintiArIvestasKintamasis{@titleEN}
		{Specify the thesis title ( \protect\titleEN{Title of the Final Thesis} )}
		{\Large \textbf{\color{VU}\@titleEN}}
		\vspace{2\baselineskip}
		
		\patikrintiArIvestasKintamasis{@thesistype}
		{Specify the thesis type ( command \protect\thesistype{Thesis type} )}
		{\normalsize \textbf{\@thesistype}}
		\vspace{1\baselineskip}
		
		\patikrintiArIvestasKintamasis{@studyprogram}
		{Specify your study program ( command \protect\studyprogram{Study program} )}
		{\normalsize \@studyprogram}
		\vspace{3\baselineskip}	
			
		\hfill
	 	\begin{minipage}{0.5\linewidth}
	    \begin{flushleft}
		  	\begin{normalsize}
		  		\patikrintiArIvestasKintamasis{@supervisor}
		  		{Specify the thesis supervisor ( command \protect\supervisor[Supervisor:]{Name Surname} )}
	        \textit{\@supervisor}\\
	        \ifx \@supervisorpirmas \@empty
	        \relax
	        \else
	        \vspace{0.2\baselineskip}
	        \@supervisorpirmas \\
	        \fi
	        \ifx \@supervisorantras \@empty
	        \relax
	        \else
	        \vspace{0.2\baselineskip}
	        \@supervisorantras \\
	        \fi
	        \ifx \@consultant \@empty
	        \relax
	        \else
	        \vspace{1\baselineskip}
	        \textit{\@consultantVM} \\
	        \vspace{0.2\baselineskip}
	        \@consultant \@empty \\
	        \fi
	        \patikrintiArIvestasKintamasis{@department}
	        {Specify your department/sector ( command \protect\department{Department} )}
	        \vspace{1\baselineskip}
	        \textit{\@departmentPR} \\
	        \vspace{0.2\baselineskip}
	        \@department
	      \end{normalsize}	
			\end{flushleft}	
	  \end{minipage} 
			
		\vfill
		{\normalsize {\@vieta}\hspace{0.8em}{\@metai}	}	
	\end{center}
}
\end{titlepage}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lietuviška santrauka:
\newenvironment{santrauka}[2]{%
\clearpage
\phantomsection
\addcontentsline{toc}{section}{\santraukosPavLT}
\markboth{\santraukosPavLT}{}
\pagestyle{fancy}
\fancyfoot[R]{\small \textsf{\thepage}} 		
\renewcommand{\headrulewidth}{0.4pt}
\begin{center}
{\sffamily	
	\MakeUppercase{\VUGMC} \\
	\vspace{0.8\baselineskip}
	\textbf{\@thesisauthor} \\
	\vspace{0.3\baselineskip}
	{#1} \\
	\vspace{0.8\baselineskip}
	\textbf{\large \@titleLT}\\
	\vspace{0.8\baselineskip}
	\MakeUppercase{\santraukosPavLT}
}
\end{center} 
#2
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Angliška santrauka:
\newenvironment{summary}[2]{
\clearpage
\phantomsection
\addcontentsline{toc}{section}{\santraukosPavEN}
\markboth{\santraukosPavEN}{}
\pagestyle{fancy}
\fancyfoot[R]{\small \textsf{\thepage}} 		
\renewcommand{\headrulewidth}{0.4pt}
\patikrintiArIvestasKintamasis{@titleEN}
{Document title should be provided ( use command \protect\titleEN{Thesis title} )}
\begin{center}
{\sffamily	
	\MakeUppercase{\VUGMCen} \\
	\vspace{0.8\baselineskip}
	\textbf{\@thesisauthor} \\
	\vspace{0.3\baselineskip}
	{#1} \\
	\vspace{0.8\baselineskip}
	\textbf{\large \@titleEN}\\
	\vspace{0.8\baselineskip}
	\MakeUppercase{\santraukosPavEN}
}
\end{center} 
#2
}


% Unnumbered sections definition
\newcommand{\sectionnonumber}[1]
{
	\section*{#1}
	\markboth{#1}{} 
	\phantomsection	
	\addcontentsline{toc}{section}{#1} 
}

% Single spacing in TOC:
\renewcommand\tableofcontents
{
	\begin{singlespacing}
		\section*{\contentsname\@mkboth{\contentsname}{\contentsname}}
		\@starttoc{toc}
	\end{singlespacing}
	\newpage
}

% Dot spacing in TOC:
\renewcommand{\@dotsep}{4}

% 1.5 line spacing in the document:
\onehalfspacing

\selectlanguage{english}

% Redefinition of separators in the section numbers:
\titlelabel{\thetitle.\quad}
% Section should start at new page:
\let\stdsection\section
\renewcommand\section{\clearpage\stdsection}
\let\tocnumdot\numberline
\def\numberline#1{\tocnumdot{#1.}}
\titleformat*{\section}{\Large\bfseries\sffamily}
\titleformat*{\subsection}{\large\bfseries\sffamily}
\titleformat*{\subsubsection}{\normalsize\bfseries\sffamily}
\titleformat*{\paragraph}{\normalsize\bfseries\sffamily}


% Headings style:
\renewcommand{\sectionmark}[1]{\markboth{#1}{#1}}
\fancyhf{}
\fancyhead[L]{\textsf{{\small }}}
\fancyhead[R]{\nouppercase{\textsf{{\small \leftmark}}}}
\fancyfoot[R]{\small \textsf{\thepage}} 
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0.0pt}
\setlength{\voffset}{10pt}
\setlength{\headheight}{12pt}
\setlength{\headsep}{14pt}
\setlength{\footskip}{18pt}

% Appendices: 
\newcounter{prieduskyrius}
\renewcommand{\appendix}
{
	\cleardoublepage
	\pagestyle{fancy}
	\fancyhead[L]{}
	\fancyhead[R]{}
	\fancyfoot[R]{\small \textsf{\thepage}} 	
	\renewcommand{\headrulewidth}{0pt}
	\phantomsection
	\addcontentsline{toc}{section}{Appendices}
	\phantom{ }
	\vfill
	\begin{center}
		{\sffamily \Large \textbf{Appendices}}
	\end{center}
	\vfill
	\cleardoublepage
	\fancyhead[R]{\nouppercase{\textsf{{\small \leftmark}}}}
	\renewcommand{\headrulewidth}{0.4pt}
	
	\renewcommand{\section}
	{
		\cleardoublepage
		\secdef\@Appendix\@sAppendix
	}
	\setcounter{prieduskyrius}{0}
	\renewcommand{\thesection}{\sffamily Appendix \Alph{prieduskyrius}.}
	
}

\def\@Appendix[#1]#2
{
\refstepcounter{prieduskyrius}
\cftaddtitleline{toc}{subsection}{Appendix \Alph{prieduskyrius}.~#1}{\thepage}
{\large\bfseries\thesection~~#2\par}
\sectionmark{#1}\vspace{\baselineskip}
}

\def\@sAppendix#1{
{\flushright\large\bfseries\appendixname\par
\centering#1\par}
\vspace{\baselineskip}
}


